@@ -10,8 +10,8 @@ __credits__  = "Yegor Shershnev"
 __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
-from dictannotation.interfaces import IDictAnnotation
-from anytitlesubscriberbase import AnyTitileSubscriberBase
+from interfaces import IDictAnnotation
+from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitileSubscriberBase
 
 class DictAnnotation2TitleSubscriber( AnyTitileSubscriberBase ) :
 
