@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id: interfaces.py 49625 2008-01-21 15:22:18Z cray $
+$Id: interfaces.py 49878 2008-02-02 14:28:40Z cray $
 """
 __author__  = "Elena Antusheva, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49625 $"
+__version__ = "$Revision: 49878 $"
  
 from zope.interface import Interface
 
@@ -17,11 +17,13 @@ from zope.app.container.constraints import ContainerTypesConstraint
 from zope.schema import Choice
 from zope.schema.vocabulary import SimpleVocabulary
 
+
 class IDictAnnotationAble(Interface) :
     pass
 
 class IDictAnnotation(Interface) :
     """ """
+
     keyword = Tuple(title=u'keywords',
                     description=u'Some keywords',
                     required=False,
@@ -30,13 +32,15 @@ class IDictAnnotation(Interface) :
                    )
                 
     gender = Choice(title=u'gender',
-                  vocabulary = SimpleVocabulary.fromValues(['F','M'])
+                  vocabulary = SimpleVocabulary.fromValues([u'Male','Middle',u'Female']),
+                  required=False,
                   )
 
-    suffixes = TextLine(title=u'suffixes')
+    suffixes = TextLine(title=u'suffixes',required=False)
 
     area = Choice(title=u'Area',
-                  vocabulary = SimpleVocabulary.fromValues([1, 2, 3])
+                  vocabulary = SimpleVocabulary.fromValues([u"Zope", u"NeuralNetwork", u"Programming", u"Other"]),
+                  required=False
                   )
 
 dictannotationkey="dictannotation.dictannotation.DictAnnotation"
