@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id: interfaces.py 49625 2008-01-21 15:22:18Z cray $
+$Id: interfaces.py 49878 2008-02-02 14:28:40Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49625 $"
+__version__ = "$Revision: 49878 $"
  
 from zope.interface import Interface
 
@@ -35,9 +35,10 @@ class IEventAnnotation(Interface) :
     durability = TextLine(
         title = u"Durability of event",
         description = u"Durability of event",
+        required=False        
         )
         
-    place = TextLine(
+    place = Text(
         title = u'Place of event',
         description = u'Place of event',
         default = u'Internet',
